@@ -3,9 +3,20 @@
 `MatWrap.configure` is called upon importing this module, which enables default config.
 """
 
+import sys
 from contextlib import AbstractContextManager
 from itertools import cycle, islice
-from typing import Annotated, Any, Literal, Optional
+from typing import Any, Optional
+
+if sys.version_info >= (3, 9):
+    from typing import Annotated, Literal
+else:
+    from typing_extensions import Annotated
+
+    if sys.version_info >= (3, 8):
+        from typing import Literal
+    else:
+        from typing_extensions import Literal
 
 from corgy import Corgy
 
